summaryrefslogtreecommitdiffstats
path: root/lib/public/Files_FullTextSearch
diff options
context:
space:
mode:
authorMaxence Lange <maxence@artificial-owl.com>2019-02-20 09:38:19 -0100
committerMaxence Lange <maxence@artificial-owl.com>2019-03-04 09:54:45 -0100
commita644ad5793b75f6cb4a5ddcd6ac33619764db738 (patch)
tree9ec50b694b00469970998e1cc9c252dafacc2b35 /lib/public/Files_FullTextSearch
parent358c9e649bebdc82424b999e9941c37541e730ea (diff)
downloadnextcloud-server-a644ad5793b75f6cb4a5ddcd6ac33619764db738.tar.gz
nextcloud-server-a644ad5793b75f6cb4a5ddcd6ac33619764db738.zip
moving final class to private, new interface in public
Signed-off-by: Maxence Lange <maxence@artificial-owl.com>
Diffstat (limited to 'lib/public/Files_FullTextSearch')
-rw-r--r--lib/public/Files_FullTextSearch/Model/AFilesDocument.php7
1 files changed, 3 insertions, 4 deletions
diff --git a/lib/public/Files_FullTextSearch/Model/AFilesDocument.php b/lib/public/Files_FullTextSearch/Model/AFilesDocument.php
index 3eed956df84..143788f33ad 100644
--- a/lib/public/Files_FullTextSearch/Model/AFilesDocument.php
+++ b/lib/public/Files_FullTextSearch/Model/AFilesDocument.php
@@ -31,13 +31,14 @@ declare(strict_types=1);
namespace OCP\Files_FullTextSearch\Model;
-use OCP\FullTextSearch\Model\IndexDocument;
+use OC\FullTextSearch\Model\IndexDocument;
+use OCP\FullTextSearch\Model\IIndexDocument;
/**
* Abstract Class AFilesDocument
*
* This is mostly used by 3rd party apps that want to complete the IndexDocument
* with more information about a file before its index:
*
* \OC::$server->getEventDispatcher()->addListener(
@@ -48,7 +49,6 @@ use OCP\FullTextSearch\Model\IndexDocument;
*
* // @var \OCP\Files_FullTextSearch\Model\AFilesDocument $document
* $document = $e->getArgument('document');
- *
* }
* );
*
@@ -107,6 +107,5 @@ abstract class AFilesDocument extends IndexDocument {
*/
abstract public function getPath(): string;
-
}
@@ -31,13 +31,14 @@ declare(strict_types=1);
* Abstract Class AFilesDocument
*
- * This is mostly used by 3rd party apps that want to complete the IndexDocument
+ * This is mostly used by 3rd party apps that want to complete the IIndexDocument
* with more information about a file before its index:
*